package com.jozki.uutils.config;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.lang.reflect.Field;
import java.util.Properties;

import com.jozki.uutils.logging.LogManager;
import com.jozki.uutils.logging.Logger;

public abstract class BaseConfig {

	private static final Logger LOG = LogManager.getLogger(BaseConfig.class);
	
	public BaseConfig() {
	}

	public abstract void setDefault();

	public void load(String filename) throws FileNotFoundException, IOException {
		try (FileInputStream f = new FileInputStream(filename)) {
			Properties p = new Properties();
			p.load(f);
			fromProperties(p);
		}
	}


	public void save(String filename) throws FileNotFoundException, IOException {
		save(filename, null);
	}

	public void save(String filename, String comments) throws FileNotFoundException, IOException {
		try (FileOutputStream f = new FileOutputStream(filename)) {
			this.toProperties().store(f, comments);
		}
	}

	public Properties toProperties() {
		Properties p = new Properties();

		for (Field f : this.getClass().getFields()) {
			try {
				p.setProperty(f.getName(), f.get(this).toString());
			} catch (Exception e) {
				LOG.warn("Field: " + f.getName() + " OUT mapping problem: " + e.getClass().getSimpleName() + ":" + e.getMessage());
			}
		}

		return p;
	}

	public void fromProperties(Properties p) {
		for (Field f : this.getClass().getFields()) {
			try {
				String value = p.getProperty(f.getName());
				Object val = null;
				if (f.getType() == boolean.class) {
					val = Boolean.valueOf(value);
				} else if (f.getType() == byte.class) {
					val = Byte.valueOf(value);
				} else if (f.getType() == char.class) {
					val = value.charAt(0);
				} else if (f.getType() == short.class) {
					val = Short.valueOf(value);
				} else if (f.getType() == int.class) {
					val = Integer.valueOf(value);
				} else if (f.getType() == long.class) {
					val = Long.valueOf(value);
				} else if (f.getType() == String.class) {
					val = String.valueOf(value);
				} else if (f.getType() == double.class) {
					val = Double.valueOf(value);
				} else if (f.getType() == float.class) {
					val = Float.valueOf(value);
				} else {
					throw new Exception("Uknown type: " + f.getType());
				}
				f.set(this, val);
			} catch (Exception e) {
				LOG.warn("Field: " + f.getName() + " IN mapping problem: " + e.getClass().getSimpleName() + ":" + e.getMessage());
			}
		}
	}

}
