package com.jozki.uutils.i18n;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

import com.jozki.uutils.logging.LogManager;
import com.jozki.uutils.logging.Logger;

public class Lang {

	private static final String DEFAULT_UKNOWN_KEY_VALUE = "???";

	private static final Logger LOG = LogManager.getLogger(Lang.class);

	private static Lang lang;
	private ResourceBundle rbundle;
	private String basename;

	private Lang() {
	}

	public static Lang getInstance() {
		if (lang == null) {
			lang = new Lang();
		}
		return lang;
	}

	public String getString(String key) {
		return getString(key, DEFAULT_UKNOWN_KEY_VALUE);
	}

	public String getString(String key, String missingString) {
		if (!checkInitialized()) {
			return missingString;
		}
		try {
			return rbundle.getString(key);
		} catch (MissingResourceException e) {
			return missingString;
		}
	}

	private boolean checkInitialized() {
		if (basename == null) {
			LOG.warn("Module not initialized");
			return false;
		}
		return true;
	}

	public String getLang() {
		if (!checkInitialized()) {
			LOG.warn("Module not initialized");
			return DEFAULT_UKNOWN_KEY_VALUE;
		}
		return rbundle.getLocale().getLanguage().toUpperCase();
	}

	public void setLang(String lang) {
		if (!checkInitialized()) {
			return;
		}
		rbundle = ResourceBundle.getBundle(basename, new Locale(lang));
		LOG.info("Language changed to '{}'", lang);
	}

	public void initialize(String basename, String lang) {
		this.basename = basename;
		setLang(lang);
	}

}
