package com.jozki.uutils.javafx;

import javafx.geometry.Point2D;
import javafx.scene.SubScene;
import javafx.scene.canvas.Canvas;
import javafx.scene.canvas.GraphicsContext;
import javafx.scene.paint.Color;

public class GraphicsContextEx {
	public static final int DEFAULT_POINT_WIDTH = 5;

	public GraphicsContext gc;

	public GraphicsContextEx(GraphicsContext gc) {
		this.gc = gc;
	}

	public GraphicsContextEx(Canvas canvas) {
		gc = canvas.getGraphicsContext2D();
	}

	public void clearScreen(SubScene scene) {
		gc.clearRect(0, 0, scene.getWidth(), scene.getHeight());
	}

	public void setStroke(Color color) {
		gc.setStroke(color);
	}

	public void setFill(Color color) {
		gc.setFill(color);
	}

	public void setStrokeAndFill(Color colorStroke, Color colorFill) {
		gc.setStroke(colorStroke);
		gc.setFill(colorFill);
	}

	public void setStrokeAndFill(Color color) {
		gc.setStroke(color);
		gc.setFill(color);
	}

	public void strokeLine(double x1, double y1, double x2, double y2) {
		gc.strokeLine(x1, y1, x2, y2);
	}

	public void strokeLine(double x1, double y1, double x2, double y2, Color color) {
		gc.setStroke(color);
		gc.strokeLine(x1, y1, x2, y2);
	}

	public void strokeLine(Point2D px1, Point2D px2) {
		gc.strokeLine(px1.getX(), px1.getY(), px2.getX(), px2.getY());
	}

	public void strokeLine(Point2D px1, Point2D px2, Color color) {
		gc.setStroke(color);
		gc.strokeLine(px1.getX(), px1.getY(), px2.getX(), px2.getY());
	}

	public void fillPoint(double x, double y, double width) {
		gc.fillOval(x - width / 2, y - width / 2, width, width);
	}

	public void fillPoint(double x, double y) {
		fillPoint(x, y, DEFAULT_POINT_WIDTH);
	}

	public void fillPoint(double x, double y, Color color) {
		gc.setFill(color);
		fillPoint(x, y, DEFAULT_POINT_WIDTH);
	}

	public void fillPoint(Point2D p) {
		fillPoint(p.getX(), p.getY(), DEFAULT_POINT_WIDTH);
	}

	public void fillPoints(Point2D... points) {
		for (Point2D p : points) {
			fillPoint(p);
		}
	}

}
