package com.jozki.uutils.javafx;

import javafx.geometry.Point2D;

/**
 * Impelementacia "priamky" vo vseobecnom tvare.
 */
public class MLine {
	double a;
	double b;
	double c;
	Point2D point;
	private Point2D normal;

	public MLine(Point2D p1, Point2D p2) {
		this(p1.getX(), p1.getY(), p2.getX(), p2.getY());
	}

	public MLine(double x1, double y1, double x2, double y2) {
		a = y2 - y1;
		b = x1 - x2;
		normal = new Point2D(a, b).normalize();
		setPoint(x1, y1);
	}

	private MLine(MLine line) {
		a = line.a;
		b = line.b;
		c = line.c;
		point = new Point2D(line.point.getX(), line.point.getY());
		normal = new Point2D(line.normal.getX(), line.normal.getY());
	}

	MLine setPoint(double x, double y) {
		point = new Point2D(x, y);
		c = -a * x - b * y;
		return this;
	}

	/**
	 * Calculates intersection point with given line.
	 * @param line
	 * @return
	 */
	public Point2D intersection(MLine line) {
		double y = (-a * line.c + c * line.a) / (-b * line.a + a * line.b);
		double x = (-b * y - c) / a;
		return new Point2D(x, y);
	}

	/**
	 * Calculates X for given Y.
	 * @param y
	 * @return
	 */
	public double getX(double y) {
		return (-b * y - c) / a;
	}

	/**
	 * Calculates Y for given X.
	 * @param x
	 * @return
	 */
	public double getY(double x) {
		return (-a * x - c) / b;
	}

	public MLine clone() {
		return new MLine(this);
	}

	public Point2D getNormal() {
		return normal;
	}
}
