package com.jozki.uutils.javafx.screen.example;

import com.jozki.uutils.javafx.screen.FxScreen;
import com.jozki.uutils.javafx.util.FxUtils;

import javafx.application.Application;
import javafx.application.Platform;
import javafx.scene.Scene;
import javafx.scene.input.KeyEvent;
import javafx.scene.layout.Pane;
import javafx.scene.paint.Color;
import javafx.scene.text.Font;
import javafx.stage.Stage;

public class FontsScreen extends FxScreen {

	int screen = 0;

	String small;
	String big;
	String numbers;

	private boolean showMonoOnly;

	public FontsScreen(Pane root) {
		super(root);

		StringBuilder sb = new StringBuilder();
		for (char c = 'a'; c <= 'z'; ++c) {
			sb.append(c);
		}
		small = sb.toString();
		sb.setLength(0);
		for (char c = 'A'; c <= 'Z'; ++c) {
			sb.append(c);
		}
		big = sb.toString();
		sb.setLength(0);
		for (char c = '0'; c <= '9'; ++c) {
			sb.append(c);
		}
		numbers = sb.toString();

		screen = 0;
		root.getScene().addEventHandler(KeyEvent.KEY_PRESSED, e -> {
			switch (e.getCode()) {
			case UP:
				if (screen > 0) {
					--screen;
				}
				onRepaint();
				return;
			case DOWN:
				++screen;
				onRepaint();
				return;
			case M:
				showMonoOnly = !showMonoOnly;
				onRepaint();
				break;
			default:
				break;
			}
		});

		onRepaint();
	}

	@Override
	protected void onRepaint() {
		gc.clearRect(0, 0, getWidth(), getHeight());
		int y = 20;

		int currentScreen = 0;
		for (int fontIndex = 0; fontIndex < Font.getFamilies().size(); ++fontIndex) {

			String fontFamily = Font.getFamilies().get(fontIndex);

			Font f = Font.font(fontFamily, 20);

			gc.setFont(f);
			if (showMonoOnly && !isMono()) {
				continue;
			}

			if (currentScreen == screen) {
				gc.setFill(Color.WHITE);
				gc.fillText(small, 0, y);
				gc.fillText(fontFamily + " SCREEN 7 " + f.getStyle() + (isMono() ? " MONO " : ""), 400, y);

			}
			y += 18;
			if (currentScreen == screen) {
				gc.fillText(big, 0, y);
				gc.fillText(numbers, 400, y);
			}

			y += 30;

			if (y > getHeight()) {
				++currentScreen;
				y = 20;
			}
		}

		if (screen > currentScreen) {
			screen = currentScreen;
			onRepaint();
		}

	}

	private int getTextWidth(String str) {
		return (int) FxUtils.getTextBounds(str, gc.getFont()).getWidth();
	}

	boolean isMono() {
		return getTextWidth(small) == getTextWidth(big);
	}

	public static void main(String[] args) {
		Application.launch(FontsScreenRunner.class, args);
	}

	public static class FontsScreenRunner extends Application {
		public FontsScreenRunner() {
		}

		@Override
		public void start(Stage primaryStage) throws Exception {
			Pane pane = new Pane();
			
			Scene scene = new Scene(pane, 1024, 768, Color.BLACK);
			
			new FontsScreen(pane);
			
			primaryStage.setTitle("FontsScreenTest");
			primaryStage.setScene(scene);
			primaryStage.setOnCloseRequest(e -> Platform.exit());
			primaryStage.sizeToScene();
			primaryStage.show();
		}
	}

}
