package com.jozki.uutils.javafx.util;

import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

import com.jozki.uutils.logging.LogManager;
import com.jozki.uutils.logging.Logger;

import javafx.geometry.Bounds;
import javafx.scene.Node;
import javafx.scene.text.Font;
import javafx.scene.text.Text;

public class FxUtils {

	private static final Logger LOG = LogManager.getLogger(FxUtils.class);

	public static Bounds getTextBounds(String text, Font font) {
		Text t = new Text(text);
		t.setFont(font);
		return t.getLayoutBounds();
	}

	@SuppressWarnings("restriction")
	public static void printFxEventHandlersOfNode(Node node) {
		if (node == null) {
			return;
		}
		LOG.info("----------------------------------------");
		LOG.info(" Searching for dispatcher in node: " + node);
		LOG.info("----------------------------------------");
		Method[] methods = Node.class.getDeclaredMethods();
		for (Method method : methods) {

			if (method.getName().equals("getInternalEventDispatcher")) {
				com.sun.javafx.scene.NodeEventDispatcher dispatcher = null;
				try {
					method.setAccessible(true);
					dispatcher = (com.sun.javafx.scene.NodeEventDispatcher) method.invoke(node);
				} catch (IllegalAccessException | IllegalArgumentException | InvocationTargetException e) {
					e.printStackTrace();
				}
				LOG.info("getInternalEventDispatcher: " + dispatcher);
				if (dispatcher == null) {
					return;
				}

				// we got the event manager, now pick the eventHandlerMap field
				com.sun.javafx.event.EventHandlerManager eventManager = dispatcher.getEventHandlerManager();
				Field[] fields = eventManager.getClass().getDeclaredFields();
				for (Field field : fields) {
					if (field.getName().equals("eventHandlerMap")) {
						field.setAccessible(true);
						try {
							LOG.info("eventHandlerMap: " + field.get(eventManager));
						} catch (IllegalArgumentException | IllegalAccessException e) {
							e.printStackTrace();
						}
					}
				}
			}
		}
		LOG.info("----------------------------------------");
	}
}
