package com.jozki.uutils.logging;

import java.io.FileNotFoundException;
import java.io.InputStream;
import java.util.Properties;

import com.jozki.uutils.logging.Logger.LoggerLevel;

public class Config {

	private static final String CONFIG_LEVEL_PROPERTY = "level";
	private static final String CONFIG_APPENDERS_PROPERTY = "appenders";
	private static final String CONFIG_APPENDERS_CONSOLE_VALUE = "console";
	private static final String CONFIG_APPENDERS_FILE_VALUE = "file";

	private LoggerLevel level;
	private Properties properties;

	public Config() {
		properties = new Properties();
	}

	public void load(String filename) {
		try (InputStream f = getClass().getClassLoader().getResourceAsStream(filename)) {
			if (f == null) {
				throw new FileNotFoundException("File does not exist");
			}
			Properties p = new Properties();
			p.load(f);
			properties = p;
		} catch (Exception e) {
			System.err.println("WARN! jjLogger config " + filename + " problem: '" + e.getMessage() + "'. Using default console logging.");
			properties = new Properties();
			properties.setProperty(CONFIG_APPENDERS_PROPERTY, "console");
		}
		if ((level = getLevelProperty(CONFIG_LEVEL_PROPERTY)) == null) {
			level = LoggerLevel.TRACE;
		}
	}

	public boolean isConsoleAppender() {
		if (properties.containsKey(CONFIG_APPENDERS_PROPERTY)) {
			return properties.getProperty(CONFIG_APPENDERS_PROPERTY).contains(CONFIG_APPENDERS_CONSOLE_VALUE);
		}
		return false;
	}

	public boolean isFileAppender() {
		if (properties.containsKey(CONFIG_APPENDERS_PROPERTY)) {
			return properties.getProperty(CONFIG_APPENDERS_PROPERTY).contains(CONFIG_APPENDERS_FILE_VALUE);
		}
		return false;
	}

	public String getProperty(String propertyName) {
		return properties.getProperty(propertyName);
	}

	/**
	 * Returns {@link LoggerLevel} property if exists in config. If not or is not parseable then <em>null</em> is returned.
	 * @param propertyName
	 * @return
	 */
	public LoggerLevel getLevelProperty(String propertyName) {
		try {
			String str = properties.getProperty(propertyName);
			return LoggerLevel.valueOf(str != null ? str.toUpperCase() : str);
		} catch (Exception e) {
			return null;
		}
	}

	/**
	 * Returns boolean property value if exists in config. If not then <em>false</em> is returned.
	 * @param propertyName
	 * @return
	 */
	public boolean getBooelanProperty(String propertyName) {
		try {
			String str = properties.getProperty(propertyName);
			return Boolean.valueOf(str);
		} catch (Exception e) {
			return false;
		}
	}

	public boolean isProperty(String propertyName) {
		String value = properties.getProperty(propertyName);
		return value != null && value.trim().length() > 0;
	}

	public LoggerLevel getLogLevel() {
		return level;
	}

	public void setLogLevel(LoggerLevel level) {
		this.level = level;
	}

}
