package com.jozki.uutils.logging;

import java.io.FileNotFoundException;
import java.util.LinkedList;
import java.util.List;

import com.jozki.uutils.logging.Logger.LoggerLevel;
import com.jozki.uutils.logging.appender.Appender;
import com.jozki.uutils.logging.appender.ConsoleAppender;
import com.jozki.uutils.logging.appender.FileAppender;

/**
 * TODO logger work
 * -some formatters
 */
public class LogManager {

	private static final String JJLOGGER_PROPERTIES_FILENAME = "ulogger.properties";

	private static LogManagerImpl instance;

	public static LogManagerImpl getInstance() {
		if (instance == null) {
			instance = new LogManagerImpl();
		}
		return instance;
	}

	public static Logger getLogger(Class<?> class1) {
		return getLogger(class1.getSimpleName());
	}

	public static Logger getLogger(String name) {
		return getInstance().getLogger(name);
	}

	public static Logger getLogger() {
		String classname = Thread.currentThread().getStackTrace()[2].getClassName();
		int dotIndex = classname.lastIndexOf('.');
		if (dotIndex != -1) {
			classname = classname.substring(dotIndex + 1);
		}
		return getLogger(classname);
	}

	public static void setLevel(LoggerLevel level) {
		getInstance().setLevel(level);
	}

	public static class LogManagerImpl {

		private List<Logger> loggers = new LinkedList<>();
		private List<Appender> appenders = new LinkedList<>();

		private Config config = new Config();

		public LogManagerImpl() {
			config.load(JJLOGGER_PROPERTIES_FILENAME);

			if (config.isConsoleAppender()) {
				appenders.add(new ConsoleAppender(config));
			}
			if (config.isFileAppender()) {
				try {
					appenders.add(new FileAppender(config));
				} catch (FileNotFoundException e) {
					System.err.println("WARN! FileAppender not created: " + e.getMessage());
				}
			}
		}

		private Logger getLogger(String name) {
			Logger logger = new Logger(name, config.getLogLevel());
			loggers.add(logger);
			return logger;
		}

		private void setLevel(LoggerLevel level) {
			config.setLogLevel(level);
			for (Logger logger : loggers) {
				logger.setLevel(level);
			}
		}

		public void append(String loggerName, long logTime, LoggerLevel level, String msg) {
			for (Appender appender : appenders) {
				appender.append(loggerName, logTime, level, msg);
			}
		}

		public void addAppender(Appender appender) {
			appenders.add(appender);
		}
	}
}
