package com.jozki.uutils.logging.appender;

import com.jozki.uutils.logging.Config;
import com.jozki.uutils.logging.Logger.LoggerLevel;

public class ConsoleAppender implements Appender {

	private static final String CONFIG_CONSOLE_APPENDER_PROPERTY_PREFIX = "console.";
	private static final String CONFIG_CONSOLE_APPENDER_LOGLEVEL_PROPERTY = CONFIG_CONSOLE_APPENDER_PROPERTY_PREFIX + "level";

	private LoggerLevel level;

	public ConsoleAppender(Config config) {
		if ((level = config.getLevelProperty(CONFIG_CONSOLE_APPENDER_LOGLEVEL_PROPERTY)) == null) {
			level = config.getLogLevel();
		}
	}

	@Override
	public void append(String loggerName, long logTime, LoggerLevel level, String msg) {
		if (!this.level.pass(level)) {
			return;
		}

		StringBuilder sb = new StringBuilder();
		sb.append(Appender.formatTime("HH:mm:ss:SSS")).append(" ");

		String levelTxt = level.toString();
		if (!levelTxt.isEmpty()) {
			sb.append(levelTxt).append(" ");
		}
		sb.append(loggerName).append(" ");
		sb.append(msg);

		if (level == LoggerLevel.ERROR) {
			System.err.println(sb.toString());
		} else {
			System.out.println(sb.toString());
		}
	}
}
