package com.jozki.uutils.logging.appender;

import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.PrintStream;

import com.jozki.uutils.logging.Config;
import com.jozki.uutils.logging.Logger.LoggerLevel;

public class FileAppender implements Appender {

	private static final String CONFIG_FILE_APPENDER_PROPERTY_PREFIX = "file.";
	private static final String CONFIG_FILE_APPENDER_FILENAME_PROPERTY = CONFIG_FILE_APPENDER_PROPERTY_PREFIX + "filename";
	private static final String CONFIG_FILE_APPENDER_LOGLEVEL_PROPERTY = CONFIG_FILE_APPENDER_PROPERTY_PREFIX + "level";
	private static final String CONFIG_FILE_APPENDER_APPEND_PROPERTY = CONFIG_FILE_APPENDER_PROPERTY_PREFIX + "append";

	private PrintStream stream;
	private LoggerLevel level;
	private boolean append;

	public FileAppender(Config config) throws FileNotFoundException {
		if ((level = config.getLevelProperty(CONFIG_FILE_APPENDER_LOGLEVEL_PROPERTY)) == null) {
			level = config.getLogLevel();
		}
		append = config.getBooelanProperty(CONFIG_FILE_APPENDER_APPEND_PROPERTY);
		init(config.getProperty(CONFIG_FILE_APPENDER_FILENAME_PROPERTY), level);
	}

	public FileAppender(String filename, LoggerLevel level) throws FileNotFoundException {
		init(filename, level);
	}

	private void init(String filename, LoggerLevel level) throws FileNotFoundException {
		this.level = level;
		if (filename == null || filename.trim().length() == 0) {
			throw new FileNotFoundException("File appender filename not specified");
		}
		stream = new PrintStream(new FileOutputStream(filename, append), true);
	}

	@Override
	public void append(String loggerName, long logTime, LoggerLevel level, String msg) {
		if (!this.level.pass(level)) {
			return;
		}
		
		StringBuilder sb = new StringBuilder();
		sb.append(Appender.formatTime("yyyy-MM-dd HH:mm:ss:SSS")).append(" ");

		String levelTxt = level.toString();
		if (!levelTxt.isEmpty()) {
			sb.append(levelTxt).append(" ");
		}
		sb.append(loggerName).append(" ");
		sb.append(msg);

		stream.println(sb.toString());
		//stream.flush();
	}
}
