package com.jozki.uutils.config;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Paths;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

public class BaseConfigTest {

	class Config extends BaseConfig {
		
		public String stringValue;
		public boolean booleanValue;
		
		public byte byteValue;
		public char charValue;
		public short shortValue;
		public int intValue;
		public long longValue;
		
		public float floatValue;
		public double doubleValue;

		@Override
		public void setDefault() {
			stringValue = "str";
			booleanValue = true;
			
			byteValue = 7;
			charValue = 'A';
			shortValue = 77;
			intValue = 777;
			longValue = 7777;
			
			floatValue = 201.2f;
			doubleValue = 101.1;
		}
	}
	
	@Test
	void loadSaveTest() throws FileNotFoundException, IOException {
		String configFilename = "test-config.txt";
		
		Config c = new Config();
		c.setDefault();
		c.save(configFilename);
		//System.out.println(c.toProperties());

		// load saved
		c = new Config();
		c.stringValue = "x";
		c.load(configFilename);
		//System.out.println(c.toProperties());

		Config defaultConfig = new Config();
		defaultConfig.setDefault();
		Assertions.assertEquals(defaultConfig.stringValue, c.stringValue);
		Assertions.assertEquals(defaultConfig.booleanValue, c.booleanValue);
		
		Assertions.assertEquals(defaultConfig.byteValue, c.byteValue);
		Assertions.assertEquals(defaultConfig.charValue, c.charValue);
		Assertions.assertEquals(defaultConfig.shortValue, c.shortValue);
		Assertions.assertEquals(defaultConfig.longValue, c.longValue);
		Assertions.assertEquals(defaultConfig.intValue, c.intValue);
		
		Assertions.assertEquals(defaultConfig.floatValue, c.floatValue, 0.1);
		Assertions.assertEquals(defaultConfig.doubleValue, c.doubleValue, 0.1);
		
		Files.deleteIfExists(Paths.get(configFilename));
	}
}
